@@ -5,4 +5,4 @@
 #'   for comparison.
 #' @seealso \code{\link{SMI}}, \code{\link{plot.SMI}} (print.SMI/summary.SMI), \code{\link{RV}} (RV2/RVadj), \code{\link{r1}} (r2/r3/r4/GCD), \code{\link{allCorrelations}} (matrix correlation comparison).
 #' @name MatrixCorrelation
-NULL
+"_PACKAGE"
